Amelia integration
==================

*libadalina-analytics* can be easily integrated within the *Amelia* platform since both are designed to
work with pandas DataFrames.

*libadalina-analytics* can be installed in an *Amelia* Jupyter Notebook environment using :code:`pip` and
then it can be referenced to use its functionalities.

In the following, a series of examples of use of *libadalina-analytics* within *Amelia* are provided.

.. WARNING::

   Package :code:`ameliadp_sql_toolkit` is not publicly available at the moment, so this example
   can be run only in an *Amelia* Jupyter Notebook environment.

.. toctree::

   /_collections/notebooks/amelia/read_osm_graph.ipynb
   /_collections/notebooks/amelia/relocation_algorithm.ipynb
   /_collections/notebooks/amelia/flows_distributions.ipynb
